Create AmplitudeTier from PointProcess and Sound
Source:R/amplitudetier-wrapper.R
amplitude_tier_from_point_process.RdExtracts amplitude values from a Sound at the times specified by a PointProcess.
R/amplitudetier-wrapper.R
amplitude_tier_from_point_process.RdExtracts amplitude values from a Sound at the times specified by a PointProcess.