Computes mean, standard deviation, min, and max of durations using SIMD.
Examples
duration_statistics_simd_bridge(c(0.5, 0.8, 1.2, 0.3))
#> $mean
#> [1] 0.7
#>
#> $stdev
#> [1] 0.391578
#>
#> $min
#> [1] 0.3
#>
#> $max
#> [1] 1.2
#>
Computes mean, standard deviation, min, and max of durations using SIMD.
duration_statistics_simd_bridge(c(0.5, 0.8, 1.2, 0.3))
#> $mean
#> [1] 0.7
#>
#> $stdev
#> [1] 0.391578
#>
#> $min
#> [1] 0.3
#>
#> $max
#> [1] 1.2
#>