Extract all point times from a PointProcess object as a numeric vector, in a single call instead of calling `get_time(i)` in a loop.
Extract all point times from a PointProcess object as a numeric vector, in a single call instead of calling `get_time(i)` in a loop.