Returns time values for each sample using a direct computation, instead of `sound$get_sample_times()`. Still allocates memory for the result.
Returns time values for each sample using a direct computation, instead of `sound$get_sample_times()`. Still allocates memory for the result.