Finds the maximum amplitude value in a sound object. Works with both S3 praat_sound objects and R6 Sound objects.
Examples
sound <- Sound$from_values(c(0.5, -0.8, 1.0), sampling_rate = 1000)
sound_max(sound) # Returns 1.0
#> [1] 1
Finds the maximum amplitude value in a sound object. Works with both S3 praat_sound objects and R6 Sound objects.
sound <- Sound$from_values(c(0.5, -0.8, 1.0), sampling_rate = 1000)
sound_max(sound) # Returns 1.0
#> [1] 1