Finds the minimum amplitude value in a sound object. Works with both S3 praat_sound objects and R6 Sound objects.
Examples
sound <- Sound$from_values(c(0.5, -0.8, 0.2), sampling_rate = 1000)
sound_min(sound) # Returns -0.8
#> [1] -0.8
Finds the minimum amplitude value in a sound object. Works with both S3 praat_sound objects and R6 Sound objects.
sound <- Sound$from_values(c(0.5, -0.8, 0.2), sampling_rate = 1000)
sound_min(sound) # Returns -0.8
#> [1] -0.8