Skip to contents

Functions for detecting voiced and unvoiced segments in audio signals. Used primarily for AVQI implementation to extract voiced segments from continuous speech.

Value

This page documents a family of functions; see the `@return` section of each individual function (e.g. [sound_to_textgrid_silences()]) for its specific return value.

Examples

# See individual functions, e.g. ?sound_to_textgrid_silences